@@ -1,13 +1,12 @@
-import sys
-
-from PyObjCTools.TestSupport import *
 import CoreBluetooth
+from PyObjCTools.TestSupport import TestCase, min_os_level
 
-class TestCBAdvertisementData (TestCase):
+
+class TestCBAdvertisementData(TestCase):
     @min_os_level("10.9")
     def testConstants(self):
-        self.assertIsInstance(CoreBluetooth.CBErrorDomain, unicode)
-        self.assertIsInstance(CoreBluetooth.CBATTErrorDomain, unicode)
+        self.assertIsInstance(CoreBluetooth.CBErrorDomain, str)
+        self.assertIsInstance(CoreBluetooth.CBATTErrorDomain, str)
 
         self.assertEqual(CoreBluetooth.CBErrorUnknown, 0)
         self.assertEqual(CoreBluetooth.CBErrorInvalidParameters, 1)
@@ -22,6 +21,10 @@ class TestCBAdvertisementData (TestCase):
         self.assertEqual(CoreBluetooth.CBErrorConnectionFailed, 10)
         self.assertEqual(CoreBluetooth.CBErrorConnectionLimitReached, 11)
         self.assertEqual(CoreBluetooth.CBErrorUnkownDevice, 12)
+        self.assertEqual(CoreBluetooth.CBErrorUnknownDevice, 12)
+        self.assertEqual(CoreBluetooth.CBErrorOperationNotSupported, 13)
+        self.assertEqual(CoreBluetooth.CBErrorPeerRemovedPairingInformation, 14)
+        self.assertEqual(CoreBluetooth.CBErrorEncryptionTimedOut, 15)
 
         self.assertEqual(CoreBluetooth.CBATTErrorSuccess, 0x00)
         self.assertEqual(CoreBluetooth.CBATTErrorInvalidHandle, 0x01)
@@ -41,6 +44,3 @@ class TestCBAdvertisementData (TestCase):
         self.assertEqual(CoreBluetooth.CBATTErrorInsufficientEncryption, 0x0F)
         self.assertEqual(CoreBluetooth.CBATTErrorUnsupportedGroupType, 0x10)
         self.assertEqual(CoreBluetooth.CBATTErrorInsufficientResources, 0x11)
-
-if __name__ == "__main__":
-    main()
